@@ -60,7 +60,7 @@ const char* GetCACustomId(int _sectionIdx)
 {
 	if (_sectionIdx>=0 && _sectionIdx<SNM_MAX_CA_SECTIONS)
 	{
-		SECTION_INFO_T *info = SNM_GetActionSectionInfo(_sectionIdx);
+		const SECTION_INFO_T *info = SNM_GetActionSectionInfo(_sectionIdx);
 		if (info) return info->ca_cust_id;
 	}
 	return "";
@@ -78,7 +78,7 @@ const char* GetCAIniSection(int _sectionIdx)
 {
 	if (_sectionIdx>=0 && _sectionIdx<SNM_MAX_CA_SECTIONS)
 	{
-		SECTION_INFO_T *info = SNM_GetActionSectionInfo(_sectionIdx);
+		const SECTION_INFO_T *info = SNM_GetActionSectionInfo(_sectionIdx);
 		if (info) return info->ca_ini_sec;
 	}
 	return "";
@@ -495,7 +495,7 @@ int PerformSingleCommand(int _section, const char* _cmdStr, int _val, int _valhw
 				case SNM_SEC_IDX_ME:
 				case SNM_SEC_IDX_ME_EL:
 					return MIDIEditor_LastFocused_OnCommand(cmdId, _section==SNM_SEC_IDX_ME_EL);
-				case SNM_SEC_IDX_EPXLORER:
+				case SNM_SEC_IDX_EXPLORER:
 					if (HWND h = GetReaHwndByTitle(__localizeFunc("Media Explorer", "explorer", 0))) {
 						SendMessage(h, WM_COMMAND, cmdId, 0);
 						return 1;
@@ -1585,9 +1585,9 @@ void Cancel(bool _checkSave)
 	AllEditListItemEnd(false);
 
 	// not used ATM: _checkSave is always false
-	if (_checkSave && g_edited && 
+	if (_checkSave && g_edited &&
 			IDYES == MessageBox(g_caWndMgr.GetMsgHWND(),
-				__LOCALIZE("Save cycle actions before quitting editor ?","sws_DLG_161"),
+				__LOCALIZE("Save cycle actions before quitting editor?","sws_DLG_161"),
 				__LOCALIZE("S&M - Confirmation","sws_DLG_161"), MB_YESNO))
 	{
 		SaveCyclactions(g_editedActions);
@@ -2124,6 +2124,36 @@ void AddOrInsertCommand(const char* _cmd, int _flags = 0)
 	}
 }
 
+static bool IsSectionEnabled(const int sec)
+{
+	switch (sec)
+	{
+	case SNM_SEC_IDX_MAIN_ALT:
+		return false;
+	case SNM_SEC_IDX_CE:
+		return CrossfadeEditor_OnCommand != nullptr;
+	default:
+		return true;
+	}
+}
+
+static void WarnDisabledSection(const int sec)
+{
+	char msg[256];
+
+	switch (sec)
+	{
+	case SNM_SEC_IDX_MAIN_ALT:
+		snprintf(msg, sizeof(msg), "%s", __LOCALIZE("The \"Main (alt recording)\" section is deprecated in the Cycle Action editor.\n\nCreate the action in the \"Main\" section and add a shortcut in the Action List's \"Main (alt recording)\" section instead.", "sws_DLG_161"));
+		break;
+	default:
+		snprintf(msg, sizeof(msg), __LOCALIZE_VERFMT("The \"%s\" section is unavailable in this version of REAPER.", "sws_DLG_161"), SNM_GetActionSectionName(sec));
+		break;
+	}
+
+	MessageBox(g_caWndMgr.GetMsgHWND(), msg, __LOCALIZE("S&M - Warning", "sws_DLG_161"), MB_OK);
+}
+
 void CyclactionWnd::OnCommand(WPARAM wParam, LPARAM lParam)
 {
 	KbdSectionInfo* kbdSec = SNM_GetActionSection(g_editedSection);
@@ -2160,8 +2190,14 @@ void CyclactionWnd::OnCommand(WPARAM wParam, LPARAM lParam)
 			}
 #endif
 			break;
-		case ADD_CYCLACTION_MSG: 
+		case ADD_CYCLACTION_MSG:
 		{
+			if (!IsSectionEnabled(g_editedSection))
+			{
+				WarnDisabledSection(g_editedSection);
+				break;
+			}
+
 			Cyclaction* a = new Cyclaction(__LOCALIZE("Untitled","sws_DLG_161"));
 			a->m_added = true;
 			g_editedActions[g_editedSection].Add(a);
@@ -2364,7 +2400,13 @@ void CyclactionWnd::OnCommand(WPARAM wParam, LPARAM lParam)
 		case CMBID_SECTION:
 			if (HIWORD(wParam)==CBN_SELCHANGE) {
 				AllEditListItemEnd(false);
-				UpdateSection(m_cbSection.GetCurSel());
+				int sec = m_cbSection.GetCurSel();
+				if (!IsSectionEnabled(sec) && g_cas[sec].GetSize() == 0) {
+					WarnDisabledSection(sec);
+					m_cbSection.SetCurSel(g_editedSection);
+					break;
+				}
+				UpdateSection(sec);
 			}
 			break;
 		case BTNID_UNDO:
